=======
Credits
=======

Development Lead
----------------

* Octopus McSquid <team-octopus@zalando.de>

Contributors
------------

* Darya Dedik <darya.dedik@zalando.de>
* Dominic Heger <dominic.heger@zalando.de>
* Grigory Bordyugov <grigory.bordyugov@zalando.de>
* Jie Bao <jie.bao@zalando.de>
* Marko Kolarek <marko.kolarek@zalando.de>
* Robert Muil <robert.muil@zalando.de>
* Shan Huang <shan.huang@zalando.de>
* Till Riffert <till.riffert@zalando.de>
